@@ -1,7 +1,7 @@
-from typing import List
-from enum import Enum
-from typing import Union
 from dataclasses import dataclass
+from typing import Union
+from enum import Enum
+from typing import List
 
 
 class ActivationsEnum(Enum):
@@ -207,6 +207,7 @@ class NodeType(Enum):
     OnnxReduceMean = "OnnxReduceMean"
     OnnxSqrt = "OnnxSqrt"
     Dataset = "Dataset"
+    Input = "Input"
     RepresentationBlock = "RepresentationBlock"
     GroundTruth = "GroundTruth"
     CustomLayer = "CustomLayer"
@@ -1823,6 +1824,11 @@ class Dataset:
     type: NodeType
 
 
+@dataclass
+class Input:
+    type: NodeType
+
+
 @dataclass
 class RepresentationBlock:
     type: NodeType
@@ -1916,6 +1922,6 @@ class NodeDataTypes:
                  CategoricalCrossentropy, CategoricalHinge, CosineSimilarity, Hinge, Huber, KLDivergence, LogCosh, 
                  MeanAbsoluteError, MeanAbsolutePercentageError, MeanSquaredError, MeanSquaredLogarithmicError, Poisson, 
                  SquaredHinge, Adadelta, Adagrad, Adam, Adamax, Ftrl, Nadam, RMSprop, SGD, OnnxAbs, OnnxErf, 
-                 OnnxHardSigmoid, OnnxReduceMean, OnnxSqrt, Dataset, RepresentationBlock, GroundTruth, CustomLayer, 
-                 CustomLoss, Visualizer, Metric, Lambda, TFOpLambda, SlicingOpLambda, Repeat, Variable, Gather, 
-                 FixedDropout]
+                 OnnxHardSigmoid, OnnxReduceMean, OnnxSqrt, Dataset, Input, RepresentationBlock, GroundTruth, 
+                 CustomLayer, CustomLoss, Visualizer, Metric, Lambda, TFOpLambda, SlicingOpLambda, Repeat, Variable, 
+                 Gather, FixedDropout]
